import { LitElement, html, customElement, property } from "lit-element";

export function subscribe(callback) {
  // Adds the WebSocket connection.
  // The server is also connected to this websocket so when a comment is posted,
  // every client that has this connection will receive a "message" event.
  // If you open two browsers to localhost:8000, you should be able to send messages between them.
  const ws = new WebSocket("ws://localhost:3030");

  // We listen to the "message" event, which will return a "data" property.
  // The "data" property is the stringified comment data.
  ws.addEventListener("message", (e) => {
    callback(JSON.parse(e.data));
  });
}

@customElement("chat-room")
export class ChatRoom extends LitElement {
  @property({ type: String, reflect: true }) roomid = "";
  @property({ type: String, reflect: true }) userid = "";

  subscribeCallback = (comment) => {};

  firstUpdated() {
    // Connects to the WebSocket. When a comment gets posted to localhost:3000, this.subscribeCallback will fire.
    subscribe(this.subscribeCallback);
  }

  render() {
    return html``;
  }
}

declare global {
  interface HTMLElementTagNameMap {
    "chat-room": ChatRoom;
  }
}
